#
# Parameters
#
Cmyu <- 0.09
patchNames <- c("x_")
windDirectionDegree <- 45
scalez <- 1e-3 
scaleU <- 1
scalek <- 1
z0 <- 0
U0 <- 0
k0 <- 0

#
# constants
#
pi <- atan(1)*4

#
# read inflow.csv
#
inflow <- read.csv("inflow.csv") 

#
# scaling
#
z <- inflow[,"z"] * scalez
U <- inflow[,"U"] * scaleU
k <- inflow[,"k"] * scalek

#
# wall value
#
z <- c(z0,z)
U <- c(U0,U)
k <- c(k0,k)

#
# calculate dU/dz
#
Umid <- U + 0.5*(c(diff(U),0))
diffz <- diff(z)
zmid <- z + c(diff(z),diffz[length(diffz)])/2

dUdz <- diff(Umid)/diff(zmid)
dUdz <- c(0,dUdz)

#
# estimate epsilon
#
epsilon <- sqrt(Cmyu) * k * dUdz

#
# write setDiscreteFieldsDict
#
out <- file("setDiscreteFieldsDict","w")

#
# write header
#
header <- "FoamFile
{
version 2.0;
format  ascii;
class   dictionary;
object  setDiscreteFieldsDict;
}
// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

Fields
("

writeLines(header,out,sep="\n")

#
# write Uprofile
#
Uprofile <- "Uprofile
{
field U;
type vector;
direction \"z\";
internal false ;
patchNames
("

writeLines(Uprofile,out,sep="\n")
writeLines(patchNames,out,sep="\n")

Uprofile2 <- ");
profile
("

writeLines(Uprofile2,out,sep="\n")

for (i in 1:length(U)) {
  Ux <- cos(windDirectionDegree/180*pi)*U[i]
  Uy <- sin(windDirectionDegree/180*pi)*U[i]
  writeLines(sprintf("(0 0 %g %g %g 0)",z[i],Ux,Uy),out,sep="\n")
}

Uprofile3 <- ");
}"

writeLines(Uprofile3,out,sep="\n")

#
# write kProfile
#
kProfile <- "kProfile
{
field k;
type scalar;
direction \"z\";
internal false ;
patchNames
("

writeLines(kProfile,out,sep="\n")
writeLines(patchNames,out,sep="\n")

kProfile2 <- ");
profile
("

writeLines(kProfile2,out,sep="\n")

for (i in 1:length(U)) {
  writeLines(sprintf("(0 0 %g %g)",z[i],k[i]),out,sep="\n")
}

kProfile3 <- ");
}"

writeLines(kProfile3,out,sep="\n")

#
# write epsilonProfile
#
epsilonProfile <- "epsilonProfile
{
field epsilon;
type scalar;
direction \"z\";
internal false ;
patchNames
("

writeLines(epsilonProfile,out,sep="\n")
writeLines(patchNames,out,sep="\n")

epsilonProfile2 <- ");
profile
("

writeLines(epsilonProfile2,out,sep="\n")

for (i in 1:length(U)) {
  writeLines(sprintf("(0 0 %g %g)",z[i],epsilon[i]),out,sep="\n")
}

epsilonProfile3 <- ");
}"

writeLines(epsilonProfile3,out,sep="\n")

#
# write footer and close outputfile
#
footer <- ");

// ************************************************************************* //"
writeLines(footer,out,sep="\n")

close(out)
